;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elisp-dev-mcp" "1.2.0"
  "MCP server for agentic Elisp development."
  '((emacs          "27.1")
    (mcp-server-lib "0.2.0"))
  :url "https://github.com/laurynas-biveinis/elisp-dev-mcp"
  :commit "acce467f667df06e8dd391d64c5a553997dabed5"
  :revdesc "acce467f667d"
  :keywords '("tools" "development"))
